# Table of Contents

- [self-built-software-discovery](<./self-built-software-discovery.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Self-Built Software Discovery](<./Self-Built-Software-Discovery.md>)
  - [Introduction](<./Self-Built-Software-Discovery/Introduction.md>)
  - [Benefits](<./Self-Built-Software-Discovery/Benefits.md>)
  - [Getting Started with Self-Built Software Discovery](<./Self-Built-Software-Discovery/Getting-Started-with-Self-Built-Software-Discovery.md>)
  - [Self-Built Software Agent](<./Self-Built-Software-Discovery/Self-Built-Software-Agent.md>)
  - [Modeling Guidelines for Self-Built Software](<./Self-Built-Software-Discovery/Modeling-Guidelines-for-Self-Built-Software.md>)
  - [Best Practices](<./Self-Built-Software-Discovery/Best-Practices.md>)
  - [Antipatterns](<./Self-Built-Software-Discovery/Antipatterns.md>)
  - [Alternative Approach to Modeling Self-Built Software](<./Self-Built-Software-Discovery/Alternative-Approach-to-Modeling-Self-Built-Software.md>)
  - [Detailed Guides](<./Self-Built-Software-Discovery/Detailed-Guides.md>)
